summaryrefslogtreecommitdiffstats
path: root/parts/distpart/specsupport.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'parts/distpart/specsupport.cpp')
-rw-r--r--parts/distpart/specsupport.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/parts/distpart/specsupport.cpp b/parts/distpart/specsupport.cpp
index 63bfa59a..259ac301 100644
--- a/parts/distpart/specsupport.cpp
+++ b/parts/distpart/specsupport.cpp
@@ -37,7 +37,7 @@
#include <tqtabwidget.h>
#include <tqmessagebox.h>
/// \FIXME This is at least the fifth place in the kdevelop code something like this exists
TQString TQRegExp_escape(const TQString& str )
{
return TQRegExp::escape(str);
@@ -242,7 +242,7 @@ TQString SpecSupport::generatePackage( )
{
TQString spec;
spec += "# This spec file was generated by KDevelop \n";
- spec += "# Please report any problem to KDevelop Team <kdevelop-devel@kdevelop.org> \n";
+ spec += "# Please report any problem to KDevelop Team <tdevelop-devel@tdevelop.org> \n";
spec += "# Thanks to Matthias Saou for his explanations on http://freshrpms.net/docs/fight.html\n\n";
spec += "Name: " + getAppName() + "\n";
@@ -37,7 +37,7 @@
#include <tqtabwidget.h>
#include <tqmessagebox.h>
-/// \FIXME This is at least the fifth place in the kdevelop code something like this exists
+/// \FIXME This is at least the fifth place in the tdevelop code something like this exists
TQString TQRegExp_escape(const TQString& str )
{